@@ -1,8 +1,8 @@
 # -*- coding: utf-8 -*-
 
 __title__ = 'CryptoLyzer'
-__version__ = '0.5.0'
-__description__ = 'Fast and flexible cryptographic protocol analyzer'
+__version__ = '0.7.2'
+__description__ = 'Fast and flexible server cryptographic (TLS/SSL/SSH) settings analyzer library for Python with CLI'
 __author__ = 'Szilárd Pfeiffer'
 __author_email__ = 'coroner@pfeifferszilard.hu'
 __url__ = 'https://gitlab.com/coroner/cryptolyzer'
